@@ -3,11 +3,13 @@
 """
 A Rocket fetches a FireWork from the database, runs the sequence of FireTasks inside, and then completes the Launch
 """
+import multiprocessing
 import os
 import traceback
 import threading
 from fireworks.core.firework import FWAction
-from fireworks.core.fw_config import FWConfig
+from fireworks.core.fw_config import FWConfig, FWData
+from fireworks.utilities.fw_utilities import release_db_lock
 
 __author__ = 'Anubhav Jain'
 __copyright__ = 'Copyright 2013, The Materials Project'
@@ -19,10 +21,32 @@ __date__ = 'Feb 7, 2013'
 
 def ping_launch(launchpad, launch_id, stop_event, master_thread):
     while not stop_event.is_set() and master_thread.isAlive():
-        launchpad._ping_launch(launch_id)
+        launchpad.ping_launch(launch_id)
         stop_event.wait(FWConfig().PING_TIME_SECS)
 
 
+def start_ping_launch(launch_id, lp):
+    fd = FWData()
+    if fd.MULTIPROCESSING:
+        m = fd.DATASERVER
+        m.Running_IDs()[os.getpid()] = launch_id
+        return None
+    else:
+        ping_stop = threading.Event()
+        ping_thread = threading.Thread(target=ping_launch,
+                                       args=(lp, launch_id, ping_stop, threading.currentThread()))
+        ping_thread.start()
+        return ping_stop
+
+def stop_ping_launch(ping_stop):
+    fd = FWData()
+    if fd.MULTIPROCESSING:
+        m = fd.DATASERVER
+        m.Running_IDs()[os.getpid()] = None
+    else:
+        ping_stop.set()
+
+
 class Rocket():
     """
     The Rocket fetches a workflow step from the FireWorks database and executes it.
@@ -39,17 +63,21 @@ class Rocket():
         self.fworker = fworker
         self.fw_id = fw_id
 
+
     def run(self):
         """
         Run the rocket (check out a job from the database and execute it)
         """
-        all_stored_data = {}  # stored data for *all* the Tasks
+        all_stored_data = {}  # combined stored data for *all* the Tasks
+        all_update_spec = {}  # combined update_spec for *all* the Tasks
+        all_mod_spec = []  # combined mod_spec for *all* the Tasks
 
         lp = self.launchpad
         launch_dir = os.path.abspath(os.getcwd())
 
         # check a FW job out of the launchpad
-        m_fw, launch_id = lp._checkout_fw(self.fworker, launch_dir, self.fw_id)
+        m_fw, launch_id = lp.checkout_fw(self.fworker, launch_dir, self.fw_id)
+        release_db_lock()
         if not m_fw:
             raise ValueError("No FireWorks are ready to run and match query! {}".format(self.fworker.query))
 
@@ -73,10 +101,7 @@ class Rocket():
 
         # set up heartbeat (pinging the server that we're still alive)
         try:
-            ping_stop = threading.Event()
-            ping_thread = threading.Thread(target=ping_launch,
-                                           args=(lp, launch_id, ping_stop, threading.currentThread()))
-            ping_thread.start()
+            ping_stop = start_ping_launch(launch_id, lp)
 
             # execute the FireTasks!
             for my_task in m_fw.tasks:
@@ -93,18 +118,27 @@ class Rocket():
 
                 # update the global stored data with the data to store from this particular Task
                 all_stored_data.update(m_action.stored_data)
+                all_update_spec.update(m_action.update_spec)
+                all_mod_spec.extend(m_action.mod_spec)
 
                 if m_action.skip_remaining_tasks:
-                    break;
+                    break
+
+            # add job packing info if this is needed
+            if FWData().MULTIPROCESSING and FWConfig().STORE_PACKING_INFO:
+                all_stored_data['multiprocess_name'] = multiprocessing.current_process().name
 
             # perform finishing operation
-            ping_stop.set()
+            stop_ping_launch(ping_stop)
             m_action.stored_data = all_stored_data
-            lp._complete_launch(launch_id, m_action, 'COMPLETED')
+            m_action.mod_spec = all_mod_spec
+            m_action.update_spec = all_update_spec
+            lp.complete_launch(launch_id, m_action, 'COMPLETED')
 
         except:
-            ping_stop.set()
+            stop_ping_launch(ping_stop)
             traceback.print_exc()
             m_action = FWAction(stored_data={'_message': 'runtime error during task', '_task': my_task.to_dict(),
                                              '_exception': traceback.format_exc()}, exit=True)
-            lp._complete_launch(launch_id, m_action, 'FIZZLED')
\ No newline at end of file
+            lp.complete_launch(launch_id, m_action, 'FAILED')
+
